@@ -79,6 +79,18 @@ MainWindow::MainWindow(QWidget* parent):
     viewModeGroup->addAction(ui_->actionDirTreeMode);
     viewModeGroup->addAction(ui_->actionFlatListMode);
 
+    // views icon size
+    auto viewsIconSizeGroup = new QActionGroup{this};
+    ui_->action16px->setData(16);
+    viewsIconSizeGroup->addAction(ui_->action16px);
+    ui_->action24px->setData(24);
+    viewsIconSizeGroup->addAction(ui_->action24px);
+    ui_->action32px->setData(32);
+    viewsIconSizeGroup->addAction(ui_->action32px);
+    ui_->action48px->setData(48);
+    viewsIconSizeGroup->addAction(ui_->action48px);
+    connect(viewsIconSizeGroup, &QActionGroup::triggered, this, &MainWindow::onViewsIconSizeTtriggered);
+
     // FIXME: need to add a way in libfm-qt to turn off default auto-complete
 #if 0
     auto pathBar = new Fm::PathBar{this};
@@ -166,12 +178,25 @@ void MainWindow::loadSettings() {
         winSize = winSize.boundedTo (ag);
     }
     resize(winSize);
+
+    // views icon size
+    int viewsIconSize = settings.value(QStringLiteral("ViewsIconSize"), 24).toInt();
+    setViewsIconSize(viewsIconSize);
+    if(viewsIconSize == 16)
+        ui_->action16px->setChecked(true);
+    else if(viewsIconSize == 24)
+        ui_->action24px->setChecked(true);
+    else if(viewsIconSize == 32)
+        ui_->action32px->setChecked(true);
+    else if(viewsIconSize == 48)
+        ui_->action48px->setChecked(true);
+
     // splitter position
     QList<int> sizes;
     sizes.append(settings.value(QStringLiteral("SplitterPos"), splitterPos_).toInt());
-    settings.endGroup();
     sizes.append(400);
     ui_->splitter->setSizes(sizes);
+    settings.endGroup();
     // window settings
     settings.beginGroup (QStringLiteral("Window"));
     ui_->actionDirTree->setChecked(settings.value(QStringLiteral("DirTree"), true).toBool());
@@ -194,6 +219,9 @@ void MainWindow::saveSettings() {
     if(settings.value(QStringLiteral("SplitterPos")).toInt() != splitterPos) {
         settings.setValue(QStringLiteral("SplitterPos"), splitterPos);
     }
+    if(settings.value(QStringLiteral("ViewsIconSize")).toInt() != ui_->fileListView->iconSize().width()) {
+        settings.setValue(QStringLiteral("ViewsIconSize"), ui_->fileListView->iconSize().width());
+    }
     settings.endGroup();
     // Window
     settings.beginGroup(QStringLiteral("Window"));
@@ -224,7 +252,7 @@ void MainWindow::loadFile(const Fm::FilePath &file) {
     if(!tmp.isEmpty()) {
         if(QDir(tmp).exists()) {
             tempDir_ = tmp + QStringLiteral("/lxqt-archiver-")
-                       + QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMddhhmmss"));
+                       + QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMddhhmmsszzz"));
         }
     }
 
@@ -290,6 +318,19 @@ void MainWindow::setFileName(const QString &fileName) {
     setWindowTitle(title);
 }
 
+void MainWindow::setViewsIconSize(const int &size) {
+    const QSize qs = QSize(size, size);
+    ui_->fileListView->setIconSize(qs);
+    ui_->dirTreeView->setIconSize(qs);
+    fitFileViewColumns();
+}
+
+void MainWindow::onViewsIconSizeTtriggered(QAction *action) {
+    if(action) {
+        setViewsIconSize(action->data().toInt());
+    }
+}
+
 void MainWindow::on_actionCreateNew_triggered(bool /*checked*/) {
     CreateFileDialog dlg{this};
     dlg.setDirectory(lasrDir_);
@@ -611,8 +652,8 @@ void MainWindow::onDragStarted() {
                 }
             }
             else { // wait until all files are extracted
-                connect(archiver_.get(), &Archiver::finish, this, [drag]() {
-                    if(drag && drag->exec(Qt::CopyAction) == Qt::IgnoreAction) {
+                connect(archiver_.get(), &Archiver::finish, drag, [drag]() {
+                    if(drag->exec(Qt::CopyAction) == Qt::IgnoreAction) {
                         drag->deleteLater();
                     }
                 });
@@ -684,6 +725,7 @@ void MainWindow::on_actionReload_triggered(bool /*checked*/) {
         if(!tempDir_.isEmpty()) { // remove the last temp dir
             QDir(tempDir_).removeRecursively();
         }
+        password_.clear();
         archiver_->reloadArchive(nullptr);
     }
 }
@@ -856,6 +898,17 @@ void MainWindow::onActionFinished(FrAction action, ArchiverError err) {
             if(auto model = qobject_cast<QStandardItemModel*>(ui_->dirTreeView->model())) {
                 model->clear();
             }
+
+            if(action == FR_ACTION_LISTING_CONTENT
+               && err.type() == FR_PROC_ERROR_ASK_PASSWORD
+               && password_.empty()) { // encrypted list
+                password_ = PasswordDialog::askPassword(this).toStdString();
+                if(!password_.empty()) {
+                    archiver_->reloadArchive(password_.c_str());
+                    return;
+                }
+            }
+
             QMessageBox::critical(this, tr("Error"), err.message());
             return;
         }
@@ -983,9 +1036,11 @@ QList<QStandardItem *> MainWindow::createFileListRow(const ArchiverItem *file) {
     descItem->setEditable(false);
 
     auto sizeItem = new QStandardItem{Fm::formatFileSize(file->size())};
+    sizeItem->setData(QStringLiteral("size"), ArchiverItemRole);
     sizeItem->setEditable(false);
 
     auto mtimeItem = new QStandardItem{mtime.toString(Qt::SystemLocaleShortDate)};
+    mtimeItem->setData(QStringLiteral("mTime"), ArchiverItemRole);
     mtimeItem->setEditable(false);
 
     auto encryptedItem = new QStandardItem{file->isEncrypted() ? QStringLiteral("*") : QString{}};
@@ -1025,10 +1080,6 @@ void MainWindow::showFileList(const std::vector<const ArchiverItem *> &files) {
     }
 
     if(oldModel) {
-        // Workaround for Qt 5.11 QSortFilterProxyModel bug: https://bugreports.qt.io/browse/QTBUG-68581
-#if QT_VERSION == QT_VERSION_CHECK(5, 11, 0)
-        oldModel->disconnect(this);
-#endif
         delete oldModel;
     }
 
@@ -1036,6 +1087,10 @@ void MainWindow::showFileList(const std::vector<const ArchiverItem *> &files) {
 
     ui_->statusBar->showMessage(tr("%n file(s)", "", files.size()));
 
+    fitFileViewColumns();
+}
+
+void MainWindow::fitFileViewColumns() {
     //ui_->fileListView->header()->setSectionResizeMode(0, QHeaderView::Stretch);
     QTimer::singleShot(0, this, [this] {
         // remove filtering and reapply it after resizing columns to avoid ellipses
